@@ -3,10 +3,9 @@ package Catalyst::View::Email::Template;
 use Moose;
 use Carp;
 use Scalar::Util qw/ blessed /;
-use Data::Dumper;
 extends 'Catalyst::View::Email';
 
-our $VERSION = '0.17';
+our $VERSION = '0.19';
 
 =head1 NAME
 
@@ -14,7 +13,7 @@ Catalyst::View::Email::Template - Send Templated Email from Catalyst
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
@@ -225,7 +224,6 @@ sub generate_part {
             %{$c->stash},
         }
     );
-    warn "Email output: $output";
     if ( ref $output ) {
         croak $output->can('as_string') ? $output->as_string : $output;
     }
@@ -251,7 +249,6 @@ around 'process' => sub {
     return $self->$orig( $c, @args )
       unless $c->stash->{$stash_key}->{template}
           or $c->stash->{$stash_key}->{templates};
-    warn "Stash: " . $stash_key;
 
     # in case of the simple api only one
     my @parts = ();
@@ -291,7 +288,6 @@ around 'process' => sub {
     $c->stash->{$stash_key}->{parts} ||= [];
     push @{ $c->stash->{$stash_key}->{parts} }, @parts;
     
-	warn "Stash: " . Dumper $c->stash;
     return $self->$orig($c);
 
 };
